@@ -8,10 +8,10 @@
 internal import ArgumentParser
 
 extension MAS {
-	/// Installs previously gotten apps from the Mac App Store.
+	/// Installs previously gotten apps from the App Store.
 	struct Install: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Install previously gotten apps from the Mac App Store"
+			abstract: "Install previously gotten apps from the App Store"
 		)
 
 		@OptionGroup
@@ -27,11 +27,11 @@ extension MAS {
 			}
 		}
 
-		func run(installedApps: [InstalledApp], appCatalog: some AppCatalog) async {
+		private func run(installedApps: [InstalledApp], appCatalog: some AppCatalog) async {
 			await run(installedApps: installedApps, adamIDs: await requiredAppIDsOptionGroup.appIDs.adamIDs(from: appCatalog))
 		}
 
-		func run(installedApps: [InstalledApp], adamIDs: [ADAMID]) async {
+		private func run(installedApps: [InstalledApp], adamIDs: [ADAMID]) async {
 			await adamIDs.forEach(attemptTo: "install app for ADAM ID") { adamID in
 				try await downloadApp(withADAMID: adamID, forceDownload: forceOptionGroup.force, installedApps: installedApps)
 			}
