@@ -27,15 +27,15 @@ extension MAS {
 			await run(appCatalog: ITunesSearchAppCatalog())
 		}
 
-		func run(appCatalog: some AppCatalog) async {
+		private func run(appCatalog: some AppCatalog) async {
 			await run(catalogApps: await requiredAppIDsOptionGroup.appIDs.lookupCatalogApps(from: appCatalog))
 		}
 
-		func run(catalogApps: [CatalogApp]) async {
+		func run(catalogApps: [CatalogApp]) async { // swiftformat:disable:this organizeDeclarations
 			await run(
 				sellerURLs: catalogApps.compactMap { catalogApp in
 					guard let sellerURL = catalogApp.sellerURL else {
-						MAS.printer.error("No seller website available for", catalogApp.adamID)
+						printer.error("No seller website available for", catalogApp.adamID)
 						return nil
 					}
 
@@ -44,7 +44,7 @@ extension MAS {
 			)
 		}
 
-		func run(sellerURLs: [String]) async {
+		private func run(sellerURLs: [String]) async { // swiftformat:disable:this organizeDeclarations
 			await sellerURLs.forEach(attemptTo: "open") { sellerURL in
 				guard let url = URL(string: sellerURL) else {
 					throw MASError.urlParsing(sellerURL)
