@@ -12,10 +12,10 @@ private import OrderedCollections
 private import ScriptingBridge
 
 extension MAS {
-	/// Uninstalls apps installed from the Mac App Store.
+	/// Uninstalls apps installed from the App Store.
 	struct Uninstall: AsyncParsableCommand, Sendable {
 		static let configuration = CommandConfiguration(
-			abstract: "Uninstall apps installed from the Mac App Store"
+			abstract: "Uninstall apps installed from the App Store"
 		)
 
 		/// Flag indicating that removal shouldn't be performed.
@@ -32,35 +32,36 @@ extension MAS {
 			}
 		}
 
-		func run(installedApps: [InstalledApp]) throws {
+		private func run(installedApps: [InstalledApp]) throws {
 			guard NSUserName() == "root" else {
-				throw MASError.runtimeError("Apps installed from the Mac App Store require root permission to uninstall")
+				throw MASError.runtimeError("Apps installed from the App Store require root permission to uninstall")
 			}
 
-			let uninstallingAppPaths = uninstallingAppPaths(from: installedApps)
-			guard !uninstallingAppPaths.isEmpty else {
+			let uninstallingAppPathOrderedSet = uninstallingAppPathOrderedSet(from: installedApps)
+			guard !uninstallingAppPathOrderedSet.isEmpty else {
 				return
 			}
 			guard !dryRun else {
 				printer.notice("Dry run. A wet run would uninstall:\n")
-				for uninstallingAppPath in uninstallingAppPaths {
+				for uninstallingAppPath in uninstallingAppPathOrderedSet {
 					printer.info(uninstallingAppPath)
 				}
 				return
 			}
 
-			try uninstallApps(atPaths: uninstallingAppPaths)
+			try uninstallApps(atPaths: uninstallingAppPathOrderedSet)
 		}
 
-		private func uninstallingAppPaths(from installedApps: [InstalledApp]) -> [String] {
-			var uninstallingAppPathSet = OrderedSet<String>()
-			for appID in requiredAppIDsOptionGroup.appIDs {
+		private func uninstallingAppPathOrderedSet(from installedApps: [InstalledApp]) -> OrderedSet<String> {
+			requiredAppIDsOptionGroup.appIDs.reduce(into: OrderedSet<String>()) { uninstallingAppPathSet, appID in
 				let installedAppPaths = installedApps.filter { $0.matches(appID) }.map(\.path)
-				installedAppPaths.isEmpty
-				? printer.error(appID.notInstalledMessage) // swiftformat:disable:this indent
-				: uninstallingAppPathSet.formUnion(installedAppPaths)
+				guard !installedAppPaths.isEmpty else {
+					printer.error(appID.notInstalledMessage)
+					return
+				}
+
+				uninstallingAppPathSet.formUnion(installedAppPaths)
 			}
-			return Array(uninstallingAppPathSet)
 		}
 	}
 }
@@ -69,12 +70,13 @@ extension MAS {
 ///
 /// - Parameter: appPaths: Paths to apps to be uninstalled.
 /// - Throws: An `Error` if any problem occurs.
-private func uninstallApps(atPaths appPaths: [String]) throws {
-	guard let uid = ProcessInfo.processInfo.sudoUID else {
-		throw MASError.runtimeError("Failed to get original uid")
+private func uninstallApps(atPaths appPathSequence: some Sequence<String>) throws {
+	let processInfo = ProcessInfo.processInfo
+	guard let uid = processInfo.sudoUID else {
+		throw MASError.runtimeError("Failed to get sudo uid")
 	}
-	guard let gid = ProcessInfo.processInfo.sudoGID else {
-		throw MASError.runtimeError("Failed to get original gid")
+	guard let gid = processInfo.sudoGID else {
+		throw MASError.runtimeError("Failed to get sudo gid")
 	}
 	guard let finder = SBApplication(bundleIdentifier: "com.apple.finder") as (any FinderApplication)? else {
 		throw MASError.runtimeError("Failed to obtain Finder access: bundle com.apple.finder does not exist")
@@ -84,7 +86,7 @@ private func uninstallApps(atPaths appPaths: [String]) throws {
 	}
 
 	let fileManager = FileManager.default
-	for appPath in appPaths {
+	for appPath in appPathSequence {
 		let attributes = try fileManager.attributesOfItem(atPath: appPath)
 		guard let appUID = attributes[.ownerAccountID] as? uid_t else {
 			MAS.printer.error("Failed to get uid of", appPath)
