@@ -19,7 +19,7 @@ extension MASError: CustomStringConvertible {
 	var description: String {
 		switch self {
 		case let .noCatalogAppsFound(searchTerm):
-			"No apps found in the Mac App Store for search term: \(searchTerm)"
+			"No apps found in the App Store for search term: \(searchTerm)"
 		case .notSupported:
 			"""
 			This command is not supported on this macOS version due to changes in macOS
@@ -28,7 +28,7 @@ extension MASError: CustomStringConvertible {
 		case let .runtimeError(message):
 			message
 		case let .unknownAppID(appID):
-			"No apps found in the Mac App Store for \(appID)"
+			"No apps found in the App Store for \(appID)"
 		case let .urlParsing(string):
 			"Unable to parse URL from \(string)"
 		}
